
#==============================================================================#
# $Id: config.rb,v 1.15 2005/04/14 16:54:45 yuya Exp $
#==============================================================================#

require 'rbconfig'

#==============================================================================#

module Exerb

  CORE_PATH   = [File.join(Config::CONFIG['datadir'], 'exerb'), '.']
  CORE_NAME   = {'cui' => 'ruby182c.exc', 'cuirt' => 'ruby182crt.exc', 'gui' => 'ruby182g.exc', 'guirt' => 'ruby182grt.exc'}
  PLUGIN_PATH = [File.join(Config::CONFIG['datadir'], 'exerb'), '.']
  PLUGIN_NAME = {}

  if $Exerb
    selfpath = File.dirname(Exerb.filepath)
    CORE_PATH   << selfpath
    PLUGIN_PATH << selfpath
  end

end # Exerb

#==============================================================================#

configcc = File.join(File.dirname(__FILE__), 'configcc.rb')
if File.exist?(configcc)
  require(configcc)
end

#==============================================================================#
#==============================================================================#
